@@ -1,4 +1,5 @@
 import datetime
+import math
 
 import numpy as np
 import pandas as pd
@@ -412,20 +413,21 @@ class CalcDataFrame(object):
                 # 从高净值跌到低净值
                 per_retracement: pd.Series = 1 - per_data[swanav_column] / per_data[swanav_column].expanding(
                     min_periods=1).max()
-                if len(per_retracement) != 0:
+                if len(per_retracement.dropna()) != 0:
                     edate = per_retracement.idxmax()
                     max_retracement = per_retracement[edate]
                     max_net = per_data[:edate][swanav_column].max()
                     max_net_data = per_data[per_data[swanav_column] >= max_net]
                     bdate = max_net_data[max_net_data.index < edate].index.max()
                     rdate = max_net_data[max_net_data.index > edate].index.min()
-                    rdays = (rdate - edate).days
+                    if rdate is not np.nan:
+                        rdays = (rdate - edate).days
             elif method == 'MD':
                 per_data.sort_index(ascending=False, inplace=True)
                 per_retracement: pd.Series = per_data[swanav_column].expanding(min_periods=1).min() / per_data[
                     swanav_column] - 1
                 per_data.sort_index(ascending=True, inplace=True)
-                if len(per_retracement) != 0:
+                if len(per_retracement.dropna()) != 0:
                     bdate = per_retracement.idxmin()
                     max_retracement = per_retracement[bdate]
                     min_net = per_data[bdate:][swanav_column].min()
@@ -434,7 +436,8 @@ class CalcDataFrame(object):
                     max_net = per_data[per_data.index == bdate][swanav_column].max()
                     max_net_data = per_data[per_data[swanav_column] >= max_net]
                     rdate = max_net_data[max_net_data.index > edate].index.min()
-                    rdays = (rdate - edate).days
+                    if rdate is not np.nan:
+                        rdays = (rdate - edate).days
             else:
                 raise BizException('最大回撤method错误,MF或MD')
         result[period + suffix] = max_retracement
@@ -460,7 +463,9 @@ class CalcDataFrame(object):
         stenv_a:
             不同期限的年化波动率（行列数和期限需与收益率期限对应上）
         """
-        return np.true_divide(ret_a - nrr, np.asarray(stenv_a))
+        temp = stenv_a.applymap(
+            lambda x: x if isinstance(x, int) or isinstance(x, float) else np.nan)
+        return np.true_divide(ret_a - nrr, np.asarray(temp))
 
     @staticmethod
     def get_karma(ret_a: pd.DataFrame = None, nrr: float = 0.0175, max_retracement: pd.DataFrame = None):
@@ -478,7 +483,9 @@ class CalcDataFrame(object):
         max_retracement:
             不同期限的最大回撤（行列数和期限需与收益率期限对应上）
         """
-        return np.true_divide(ret_a - nrr, np.asarray(max_retracement))
+        temp = max_retracement.applymap(
+            lambda x: x if isinstance(x, int) or isinstance(x, float) else np.nan)
+        return np.true_divide(ret_a - nrr, np.asarray(temp))
 
     @staticmethod
     def get_period_down_stdenv(data: pd.DataFrame, period: [str, list], interval_insufficient: bool = True,
@@ -604,7 +611,9 @@ class CalcDataFrame(object):
         down_stdenv:
             不同期限的下行标准差（行列数和期限需与收益率期限对应上）
         """
-        return np.true_divide(ret_a - nrr, np.asarray(down_stdenv))
+        temp = down_stdenv.applymap(
+            lambda x: x if isinstance(x, int) or isinstance(x, float) else np.nan)
+        return np.true_divide(ret_a - nrr, np.asarray(temp * math.sqrt(52)))
 
     @staticmethod
     def get_period_beta(fund_ret: pd.DataFrame, market_ret: pd.DataFrame, period: [str, list],
